@@ -1,6 +1,6 @@
 /* -*- mode: C; c-file-style: "gnu"; indent-tabs-mode: nil; -*- */
 /*
- * Copyright (C) 2011, 2013, 2014, 2015, 2016 Red Hat, Inc.
+ * Copyright (C) 2011, 2013, 2014 Red Hat, Inc.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -368,14 +368,15 @@ ensure_credentials_sync (GoaProvider         *provider,
   imap_tls_type = get_tls_type_from_object (object, "ImapUseSsl", "ImapUseTls");
 
   imap_auth = goa_imap_auth_login_new (NULL, NULL, imap_username, imap_password);
-  if (!goa_mail_client_check_sync (mail_client,
-                                   imap_server,
-                                   imap_tls_type,
-                                   imap_accept_ssl_errors,
-                                   (imap_tls_type == GOA_TLS_TYPE_SSL) ? 993 : 143,
-                                   imap_auth,
-                                   cancellable,
-                                   error))
+  ret = goa_mail_client_check_sync (mail_client,
+                                    imap_server,
+                                    imap_tls_type,
+                                    imap_accept_ssl_errors,
+                                    (imap_tls_type == GOA_TLS_TYPE_SSL) ? 993 : 143,
+                                    imap_auth,
+                                    cancellable,
+                                    error);
+  if (!ret)
     {
       if (error != NULL)
         {
@@ -399,7 +400,10 @@ ensure_credentials_sync (GoaProvider         *provider,
   /* SMTP */
 
   if (!goa_util_lookup_keyfile_boolean (object, "SmtpUseAuth"))
-    goto smtp_done;
+    {
+      ret = TRUE;
+      goto smtp_done;
+    }
 
   if (!g_variant_lookup (credentials, "smtp-password", "s", &smtp_password))
     {
@@ -424,14 +428,15 @@ ensure_credentials_sync (GoaProvider         *provider,
   email_address = goa_util_lookup_keyfile_string (object, "EmailAddress");
   goa_utils_parse_email_address (email_address, NULL, &domain);
   smtp_auth = goa_smtp_auth_new (NULL, NULL, domain, smtp_username, smtp_password);
-  if (!goa_mail_client_check_sync (mail_client,
-                                   smtp_server,
-                                   smtp_tls_type,
-                                   smtp_accept_ssl_errors,
-                                   (smtp_tls_type == GOA_TLS_TYPE_SSL) ? 465 : 587,
-                                   smtp_auth,
-                                   cancellable,
-                                   error))
+  ret = goa_mail_client_check_sync (mail_client,
+                                    smtp_server,
+                                    smtp_tls_type,
+                                    smtp_accept_ssl_errors,
+                                    (smtp_tls_type == GOA_TLS_TYPE_SSL) ? 465 : 587,
+                                    smtp_auth,
+                                    cancellable,
+                                    error);
+  if (!ret)
     {
       if (error != NULL)
         {
@@ -443,7 +448,7 @@ ensure_credentials_sync (GoaProvider         *provider,
                            */
                           _("Invalid %s with username ‘%s’ (%s, %d): "),
                           "smtp-password",
-                          smtp_username,
+                          imap_username,
                           g_quark_to_string ((*error)->domain),
                           (*error)->code);
           (*error)->domain = GOA_ERROR;
@@ -457,8 +462,6 @@ ensure_credentials_sync (GoaProvider         *provider,
   if (out_expires_in != NULL)
     *out_expires_in = 0;
 
-  ret = TRUE;
-
  out:
   g_clear_object (&imap_auth);
   g_clear_object (&smtp_auth);
@@ -471,7 +474,8 @@ ensure_credentials_sync (GoaProvider         *provider,
   g_free (smtp_password);
   g_free (smtp_server);
   g_free (smtp_username);
-  g_clear_pointer (&credentials, (GDestroyNotify) g_variant_unref);
+  if (credentials != NULL)
+    g_variant_unref (credentials);
   return ret;
 }
 
@@ -1116,7 +1120,6 @@ add_account (GoaProvider    *provider,
       gtk_widget_show_all (data.cluebar);
 
       g_clear_object (&smtp_auth);
-      g_clear_pointer (&domain, g_free);
       goto smtp_again;
     }
 
@@ -1185,7 +1188,8 @@ add_account (GoaProvider    *provider,
 
   g_free (domain);
   g_free (data.account_object_path);
-  g_clear_pointer (&data.loop, (GDestroyNotify) g_main_loop_unref);
+  if (data.loop != NULL)
+    g_main_loop_unref (data.loop);
   g_clear_object (&data.cancellable);
   g_clear_object (&imap_auth);
   g_clear_object (&smtp_auth);
@@ -1433,7 +1437,6 @@ refresh_account (GoaProvider    *provider,
       gtk_widget_show_all (data.cluebar);
 
       g_clear_object (&smtp_auth);
-      g_clear_pointer (&domain, g_free);
       goto smtp_again;
     }
 
@@ -1470,7 +1473,8 @@ refresh_account (GoaProvider    *provider,
   g_free (imap_username);
   g_free (smtp_server);
   g_free (smtp_username);
-  g_clear_pointer (&data.loop, (GDestroyNotify) g_main_loop_unref);
+  if (data.loop != NULL)
+    g_main_loop_unref (data.loop);
   g_clear_object (&data.cancellable);
   g_clear_object (&imap_auth);
   g_clear_object (&smtp_auth);
